==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/procedures/GetEvaluatedInteractionsByCampaignsAuditorsAndAgents.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEvaluatedInteractionsByCampaignsAuditorsAndAgents] (
	@Instance Varchar(50) = NULL,
	@IdAuditor VARCHAR(MAX) = NULL,
	@IdAgent Varchar(MAX) = NULL,
   	@IdCampaign VARCHAR(MAX) = NULL,
 	@EvaluationDateFrom VARCHAR(50) = '1980-01-01T00:00:00',
    @EvaluationDateTo VARCHAR(50) = '2050-01-01T23:59:59',
	@EvaluationHourFrom VARCHAR(50) = '00:00:00',
    @EvaluationHourTo VARCHAR(50) = '23:59:59',
	@InteractionMinDuration Int = 0,
    @InteractionMaxDuration Int = 86400,
    @InteractionOrigins Varchar(50) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
	@EvaluationTypes Varchar(MAX) = NULL,
	@InteractionTags Varchar(MAX) = NULL,
	@InteractionFormats Varchar(50) = NULL,
	@EvaluationsLimit Int = 0
)
AS
BEGIN
	SET NOCOUNT ON
	IF (@EvaluationHourFrom = '') SET @EvaluationHourFrom = '00:00:00';
	IF (@EvaluationHourTo = '') SET @EvaluationHourTo = '23:59:59';

	DECLARE @SQL_SELECT_0 VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';

	SET @SQL_SELECT_1 += 'SELECT ';
	SET @SQL_SELECT_1 += '
				AEP.IdInteraction					''id'',
   				AEP.[IdCampaign]					''idCampaign'',
   				AEP.[IdCampaign]					''descriptionCampaign'',
				/*AEP.[IdAuditor]						''idAuditor'',*/
 				AEP.[IdAgent]						''idAgent'',
				AEP.[InteractionDate]				''dateIni'',
   				AEP.[InteractionDuration]			''interactionTime'',
   				AEP.[InteractionType]				''interactionType'',
				AEP.[IdAgent]		                ''agentName'',
				AEP.[InteractionOrigin]				''origin'',
				AEP.[InteractionFormat]				''format'',
				AEP.[ManagementResult]				''dispositionCode'',
				AEP.[ContactId]						''address'' ';

	SET @SQL_FROM += '
			FROM EvaluationResult ER (NOLOCK) 
			LEFT JOIN [AuditorEvaluationPlan] AEP WITH (NOLOCK)
				ON (AEP.[Instance] = ER.[Instance] 
					AND AEP.[IdAuditor] = ER.[IdEvaluator] 
					AND AEP.[IdInteraction] = ER.[IdInteraction] 
					AND AEP.[InteractionType] = ER.[InteractionType] 
					AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) ';

	SET @SQL_FILTER += '
			WHERE ER.[Instance] = ''' + @Instance + '''
				AND AEP.[InteractionDate] >= ''' + @EvaluationDateFrom + '''
				AND AEP.[InteractionDate] <= ''' + @EvaluationDateTo + '''
				AND AEP.[Completed] = 1	';

	IF (@IdAuditor IS NOT NULL AND @IdAuditor != '') SET @SQL_FILTER += 'AND AEP.[IdAuditor] IN (SELECT Value FROM [dbo].[split](''' + @IdAuditor + ''','','')) ';
	IF (@IdAgent IS NOT NULL AND @IdAgent != '') SET @SQL_FILTER += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgent + ''','','')) ';
	IF (@IdCampaign IS NOT NULL AND @IdCampaign != '') SET @SQL_FILTER += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaign + ''','','')) ';
	IF (CAST(@EvaluationHourFrom AS TIME) <= CAST(@EvaluationHourTo AS TIME)) SET @SQL_FILTER += 'AND CAST(AEP.[InteractionDate] AS TIME) BETWEEN ''' + @EvaluationHourFrom + ''' AND ''' + @EvaluationHourTo + ''' ';
	IF (CAST(@EvaluationHourFrom AS TIME) > CAST(@EvaluationHourTo AS TIME)) SET @SQL_FILTER += 'AND CAST(AEP.[InteractionDate] AS TIME) NOT BETWEEN ''' + @EvaluationHourTo + ''' AND ''' + @EvaluationHourFrom + ''' ';
	IF (@InteractionMinDuration IS NOT NULL) SET @SQL_FILTER += 'AND AEP.[InteractionDuration] >= ' + (SELECT CONVERT(varchar(10), @InteractionMinDuration)) + ' ';
	IF (@InteractionMaxDuration IS NOT NULL) SET @SQL_FILTER += 'AND AEP.[InteractionDuration] <= ' + (SELECT CONVERT(varchar(10), @InteractionMaxDuration))+ ' ';
	IF (@InteractionOrigins IS NOT NULL AND @InteractionOrigins != '') SET @SQL_FILTER += 'AND AEP.[InteractionOrigin] IN (SELECT Value FROM [dbo].[split](''' + @InteractionOrigins + ''','','')) ';
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') SET @SQL_FILTER += 'AND AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')) ';
	IF (@EvaluationTypes IS NOT NULL AND @EvaluationTypes != '') 
	BEGIN
		SET @SQL_FROM += '
			LEFT JOIN [EvaluationPlan] EP WITH (NOLOCK) 
				ON (EP.[Instance] = ER.[Instance] 
					AND EP.[ID] = ER.IdEvaluationPlan) ';
		SET @SQL_FILTER += '
				AND EP.[Evaluation_Mode] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationTypes + ''','',''))  ';
	END;
	IF (@InteractionTags IS NOT NULL AND @InteractionTags != '') 
	BEGIN
		SET @SQL_FROM += '
			LEFT JOIN [Tag] T WITH (NOLOCK) 
				ON (T.[VCC] = ER.[Instance] 
					AND T.[Tag] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTags + ''','',''))) ';
		SET @SQL_FILTER += '
				AND T.[AudioId] LIKE CONCAT(AEP.[IdInteraction], ''%'') 
				AND T.[AudioId] IS NOT NULL ';
	END;
	
	-- ESTE FILTRO NO APLICA POR EL MOMENTO YA QUE LA COLUMNA FORMAT SE ESTA GUARDANDO COMO NULL
	-- IF (@InteractionFormats IS NOT NULL AND @InteractionFormats != '') SET @SQL_FILTER += 'AND AEP.[InteractionFormat] IN (SELECT Value FROM [dbo].[split](''' + @InteractionFormats + ''','','')) ';

	SET @SQL_EXTRA += '
			GROUP BY AEP.[IdInteraction],        
						AEP.[IdCampaign],        
						/*AEP.[IdAuditor],*/        
						AEP.[IdAgent],        
						AEP.[InteractionDate],        
						AEP.[InteractionDuration],        
						AEP.[InteractionType],
						AEP.[InteractionOrigin],
						AEP.[InteractionFormat],
						AEP.[ManagementResult],
						AEP.[ContactId]; ';

	SET @SQL_SELECT_1 += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA;

	--select @SQL_SELECT_1;
	EXEC (@SQL_SELECT_1);
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/GetEvaluatedInteractionsByCampaignsAuditorsAndAgents.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEvaluatedInteractionsByCampaignsAuditorsAndAgents] (
	@Instance Varchar(50) = NULL,
	@IdAuditor VARCHAR(MAX) = NULL,
	@IdAgent Varchar(MAX) = NULL,
   	@IdCampaign VARCHAR(MAX) = NULL,
 	@EvaluationDateFrom VARCHAR(50) = '1980-01-01T00:00:00',
    @EvaluationDateTo VARCHAR(50) = '2050-01-01T23:59:59',
	@EvaluationHourFrom VARCHAR(50) = '00:00:00',
    @EvaluationHourTo VARCHAR(50) = '23:59:59',
	@InteractionMinDuration Int = 0,
    @InteractionMaxDuration Int = 86400,
    @InteractionOrigins Varchar(50) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
	@EvaluationTypes Varchar(MAX) = NULL,
	@InteractionTags Varchar(MAX) = NULL,
	@InteractionFormats Varchar(50) = NULL,
	@EvaluationsLimit Int = 0,
	@ContactAddress Varchar(300) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	IF (@EvaluationHourFrom = '') SET @EvaluationHourFrom = '00:00:00';
	IF (@EvaluationHourTo = '') SET @EvaluationHourTo = '23:59:59';

	DECLARE @SQL_SELECT_0 VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';

	SET @SQL_SELECT_1 += 'SELECT ';
	SET @SQL_SELECT_1 += '
				AEP.IdInteraction					''id'',
   				AEP.[IdCampaign]					''idCampaign'',
   				AEP.[IdCampaign]					''descriptionCampaign'',
				/*AEP.[IdAuditor]						''idAuditor'',*/
 				AEP.[IdAgent]						''idAgent'',
				AEP.[InteractionDate]				''dateIni'',
   				AEP.[InteractionDuration]			''interactionTime'',
   				AEP.[InteractionType]				''interactionType'',
				AEP.[IdAgent]		                ''agentName'',
				AEP.[InteractionOrigin]				''origin'',
				AEP.[InteractionFormat]				''format'',
				AEP.[ManagementResult]				''dispositionCode'',
				AEP.[ContactAddress]						''address'' ';

	SET @SQL_FROM += '
			FROM EvaluationResult ER (NOLOCK) 
			LEFT JOIN [AuditorEvaluationPlan] AEP WITH (NOLOCK)
				ON (AEP.[Instance] = ER.[Instance] 
					AND AEP.[IdAuditor] = ER.[IdEvaluator] 
					AND AEP.[IdInteraction] = ER.[IdInteraction] 
					AND AEP.[InteractionType] = ER.[InteractionType] 
					AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) ';

	SET @SQL_FILTER += '
			WHERE ER.[Instance] = ''' + @Instance + '''
				AND AEP.[InteractionDate] >= ''' + @EvaluationDateFrom + '''
				AND AEP.[InteractionDate] <= ''' + @EvaluationDateTo + '''
				AND AEP.[Completed] = 1	';

	IF (@IdAuditor IS NOT NULL AND @IdAuditor != '') SET @SQL_FILTER += 'AND AEP.[IdAuditor] IN (SELECT Value FROM [dbo].[split](''' + @IdAuditor + ''','','')) ';
	IF (@IdAgent IS NOT NULL AND @IdAgent != '') SET @SQL_FILTER += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgent + ''','','')) ';
	IF (@IdCampaign IS NOT NULL AND @IdCampaign != '') SET @SQL_FILTER += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaign + ''','','')) ';
	IF (CAST(@EvaluationHourFrom AS TIME) <= CAST(@EvaluationHourTo AS TIME)) SET @SQL_FILTER += 'AND CAST(AEP.[InteractionDate] AS TIME) BETWEEN ''' + @EvaluationHourFrom + ''' AND ''' + @EvaluationHourTo + ''' ';
	IF (CAST(@EvaluationHourFrom AS TIME) > CAST(@EvaluationHourTo AS TIME)) SET @SQL_FILTER += 'AND CAST(AEP.[InteractionDate] AS TIME) NOT BETWEEN ''' + @EvaluationHourTo + ''' AND ''' + @EvaluationHourFrom + ''' ';
	IF (@InteractionMinDuration IS NOT NULL) SET @SQL_FILTER += 'AND AEP.[InteractionDuration] >= ' + (SELECT CONVERT(varchar(10), @InteractionMinDuration)) + ' ';
	IF (@InteractionMaxDuration IS NOT NULL) SET @SQL_FILTER += 'AND AEP.[InteractionDuration] <= ' + (SELECT CONVERT(varchar(10), @InteractionMaxDuration))+ ' ';
	IF (@InteractionOrigins IS NOT NULL AND @InteractionOrigins != '') SET @SQL_FILTER += 'AND AEP.[InteractionOrigin] IN (SELECT Value FROM [dbo].[split](''' + @InteractionOrigins + ''','','')) ';
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') SET @SQL_FILTER += 'AND AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')) ';
	IF (@EvaluationTypes IS NOT NULL AND @EvaluationTypes != '') 
	BEGIN
		SET @SQL_FROM += '
			LEFT JOIN [EvaluationPlan] EP WITH (NOLOCK) 
				ON (EP.[Instance] = ER.[Instance] 
					AND EP.[ID] = ER.IdEvaluationPlan) ';
		SET @SQL_FILTER += '
				AND EP.[Evaluation_Mode] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationTypes + ''','',''))  ';
	END;
	IF (@InteractionTags IS NOT NULL AND @InteractionTags != '') 
	BEGIN
		SET @SQL_FROM += '
			LEFT JOIN [Tag] T WITH (NOLOCK) 
				ON (T.[VCC] = ER.[Instance] 
					AND T.[Tag] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTags + ''','',''))) ';
		SET @SQL_FILTER += '
				AND T.[AudioId] LIKE CONCAT(AEP.[IdInteraction], ''%'') 
				AND T.[AudioId] IS NOT NULL ';
	END;
	IF (@ContactAddress IS NOT NULL AND @ContactAddress <> '')
	BEGIN
	SET @SQL_FILTER += '
			AND AEP.ContactAddress LIKE ''%' + @ContactAddress + '%'''
				
	END
	
	-- ESTE FILTRO NO APLICA POR EL MOMENTO YA QUE LA COLUMNA FORMAT SE ESTA GUARDANDO COMO NULL
	-- IF (@InteractionFormats IS NOT NULL AND @InteractionFormats != '') SET @SQL_FILTER += 'AND AEP.[InteractionFormat] IN (SELECT Value FROM [dbo].[split](''' + @InteractionFormats + ''','','')) ';

	SET @SQL_EXTRA += '
			GROUP BY AEP.[IdInteraction],        
						AEP.[IdCampaign],        
						/*AEP.[IdAuditor],*/        
						AEP.[IdAgent],        
						AEP.[InteractionDate],        
						AEP.[InteractionDuration],        
						AEP.[InteractionType],
						AEP.[InteractionOrigin],
						AEP.[InteractionFormat],
						AEP.[ManagementResult],
						AEP.[ContactAddress]; ';

	SET @SQL_SELECT_1 += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA;
	
	EXEC (@SQL_SELECT_1);
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
